@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -110,14 +110,17 @@ class InputConfig(proto.Message):
         text_metadata (google.cloud.datalabeling_v1beta1.types.TextMetadata):
             Required for text import, as language code
             must be specified.
+
             This field is a member of `oneof`_ ``data_type_metadata``.
         gcs_source (google.cloud.datalabeling_v1beta1.types.GcsSource):
             Source located in Cloud Storage.
+
             This field is a member of `oneof`_ ``source``.
         bigquery_source (google.cloud.datalabeling_v1beta1.types.BigQuerySource):
             Source located in BigQuery. You must specify this field if
             you are using this InputConfig in an
             [EvaluationJob][google.cloud.datalabeling.v1beta1.EvaluationJob].
+
             This field is a member of `oneof`_ ``source``.
         data_type (google.cloud.datalabeling_v1beta1.types.DataType):
             Required. Data type must be specifed when
@@ -168,8 +171,8 @@ class ClassificationMetadata(proto.Message):
 
     Attributes:
         is_multi_label (bool):
-            Whether the classification task is multi-
-            abel or not.
+            Whether the classification task is
+            multi-label or not.
     """
 
     is_multi_label = proto.Field(proto.BOOL, number=1,)
@@ -234,10 +237,12 @@ class OutputConfig(proto.Message):
             Output to a file in Cloud Storage. Should be
             used for labeling output other than image
             segmentation.
+
             This field is a member of `oneof`_ ``destination``.
         gcs_folder_destination (google.cloud.datalabeling_v1beta1.types.GcsFolderDestination):
             Output to a folder in Cloud Storage. Should
             be used for image segmentation labeling output.
+
             This field is a member of `oneof`_ ``destination``.
     """
 
@@ -293,14 +298,17 @@ class DataItem(proto.Message):
         image_payload (google.cloud.datalabeling_v1beta1.types.ImagePayload):
             The image payload, a container of the image
             bytes/uri.
+
             This field is a member of `oneof`_ ``payload``.
         text_payload (google.cloud.datalabeling_v1beta1.types.TextPayload):
             The text payload, a container of text
             content.
+
             This field is a member of `oneof`_ ``payload``.
         video_payload (google.cloud.datalabeling_v1beta1.types.VideoPayload):
             The video payload, a container of the video
             uri.
+
             This field is a member of `oneof`_ ``payload``.
         name (str):
             Output only. Name of the data item, in format of:
@@ -411,36 +419,46 @@ class AnnotatedDatasetMetadata(proto.Message):
     Attributes:
         image_classification_config (google.cloud.datalabeling_v1beta1.types.ImageClassificationConfig):
             Configuration for image classification task.
+
             This field is a member of `oneof`_ ``annotation_request_config``.
         bounding_poly_config (google.cloud.datalabeling_v1beta1.types.BoundingPolyConfig):
             Configuration for image bounding box and
             bounding poly task.
+
             This field is a member of `oneof`_ ``annotation_request_config``.
         polyline_config (google.cloud.datalabeling_v1beta1.types.PolylineConfig):
             Configuration for image polyline task.
+
             This field is a member of `oneof`_ ``annotation_request_config``.
         segmentation_config (google.cloud.datalabeling_v1beta1.types.SegmentationConfig):
             Configuration for image segmentation task.
+
             This field is a member of `oneof`_ ``annotation_request_config``.
         video_classification_config (google.cloud.datalabeling_v1beta1.types.VideoClassificationConfig):
             Configuration for video classification task.
+
             This field is a member of `oneof`_ ``annotation_request_config``.
         object_detection_config (google.cloud.datalabeling_v1beta1.types.ObjectDetectionConfig):
             Configuration for video object detection
             task.
+
             This field is a member of `oneof`_ ``annotation_request_config``.
         object_tracking_config (google.cloud.datalabeling_v1beta1.types.ObjectTrackingConfig):
             Configuration for video object tracking task.
+
             This field is a member of `oneof`_ ``annotation_request_config``.
         event_config (google.cloud.datalabeling_v1beta1.types.EventConfig):
             Configuration for video event labeling task.
+
             This field is a member of `oneof`_ ``annotation_request_config``.
         text_classification_config (google.cloud.datalabeling_v1beta1.types.TextClassificationConfig):
             Configuration for text classification task.
+
             This field is a member of `oneof`_ ``annotation_request_config``.
         text_entity_extraction_config (google.cloud.datalabeling_v1beta1.types.TextEntityExtractionConfig):
             Configuration for text entity extraction
             task.
+
             This field is a member of `oneof`_ ``annotation_request_config``.
         human_annotation_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
             HumanAnnotationConfig used when requesting
@@ -530,14 +548,17 @@ class Example(proto.Message):
         image_payload (google.cloud.datalabeling_v1beta1.types.ImagePayload):
             The image payload, a container of the image
             bytes/uri.
+
             This field is a member of `oneof`_ ``payload``.
         text_payload (google.cloud.datalabeling_v1beta1.types.TextPayload):
             The text payload, a container of the text
             content.
+
             This field is a member of `oneof`_ ``payload``.
         video_payload (google.cloud.datalabeling_v1beta1.types.VideoPayload):
             The video payload, a container of the video
             uri.
+
             This field is a member of `oneof`_ ``payload``.
         name (str):
             Output only. Name of the example, in format of:
